@@ -5,15 +5,17 @@
 // Modified by:
 // Created:
 // Copyright:   (c) Julian Smart
-// RCS-ID:      $Id: minifram.h 43031 2006-11-04 13:01:30Z VZ $
+// RCS-ID:      $Id: minifram.h 49299 2007-10-21 18:07:29Z PC $
 // Licence:     wxWindows Licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_MINIFRAM_H_BASE_
-#define _WX_MINIFRAMH_BASE_
+#define _WX_MINIFRAM_H_BASE_
 
 #include "wx/defs.h"
 
+#if wxUSE_MINIFRAME
+
 #if defined(__WXPALMOS__)
 #include "wx/palmos/minifram.h"
 #elif defined(__WXMSW__)
@@ -37,5 +39,5 @@
 typedef wxFrame wxMiniFrame;
 #endif
 
-#endif
-    // _WX_MINIFRAM_H_BASE_
+#endif // wxUSE_MINIFRAME
+#endif // _WX_MINIFRAM_H_BASE_
