@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     01/02/97
-// RCS-ID:      $Id: docview.cpp 62808 2009-12-07 15:22:45Z JS $
+// RCS-ID:      $Id: docview.cpp 66911 2011-02-16 21:31:33Z JS $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -2010,12 +2010,15 @@ bool wxDocParentFrame::ProcessEvent(wxEvent& event)
 // - must delete all frames except for the main one.
 void wxDocParentFrame::OnCloseWindow(wxCloseEvent& event)
 {
-    if (m_docManager->Clear(!event.CanVeto()))
+    if ( m_docManager && !m_docManager->Clear(!event.CanVeto()) )
+    {
+        // The user decided not to close finally, abort.
+        event.Veto();
+    }
+    else
     {
         this->Destroy();
     }
-    else
-        event.Veto();
 }
 
 #if wxUSE_PRINTING_ARCHITECTURE
