@@ -2,7 +2,7 @@
 // Name:        src/gtk/dnd.cpp
 // Purpose:     wxDropTarget class
 // Author:      Robert Roebling
-// Id:          $Id: dnd.cpp 43731 2006-12-01 14:38:39Z JJ $
+// Id:          $Id: dnd.cpp 65480 2010-09-08 20:01:32Z RR $
 // Copyright:   (c) 1998 Robert Roebling
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -901,6 +901,16 @@ wxDragResult wxDropSource::DoDragDrop(int flags)
                 g_lastButtonNumber,  // number of mouse button which started drag
                 (GdkEvent*) g_lastMouseEvent );
 
+    if ( !context )
+    {
+        // this can happen e.g. if gdk_pointer_grab() failed
+        g_blockEventsOnDrag = false;
+
+        UnregisterWindow();
+
+        return wxDragError;
+    }
+
     m_dragContext = context;
 
     PrepareIcon( action, context );
@@ -936,21 +946,27 @@ void wxDropSource::RegisterWindow()
 
 void wxDropSource::UnregisterWindow()
 {
-    if (!m_widget)
-        return;
+    if (m_widget)
+    {
+        g_signal_handlers_disconnect_by_func (m_widget,
+                                              (gpointer) source_drag_data_get,
+                                              this);
+        g_signal_handlers_disconnect_by_func (m_widget,
+                                              (gpointer) source_drag_data_delete,
+                                              this);
+        g_signal_handlers_disconnect_by_func (m_widget,
+                                              (gpointer) source_drag_begin,
+                                              this);
+        g_signal_handlers_disconnect_by_func (m_widget,
+                                              (gpointer) source_drag_end,
+                                              this);
+    }
 
-    g_signal_handlers_disconnect_by_func (m_widget,
-                                          (gpointer) source_drag_data_get,
-                                          this);
-    g_signal_handlers_disconnect_by_func (m_widget,
-                                          (gpointer) source_drag_data_delete,
-                                          this);
-    g_signal_handlers_disconnect_by_func (m_widget,
-                                          (gpointer) source_drag_begin,
-                                          this);
-    g_signal_handlers_disconnect_by_func (m_widget,
-                                          (gpointer) source_drag_end,
-                                          this);
+    if (m_iconWindow)
+    {
+        g_signal_handlers_disconnect_by_func (m_iconWindow,
+                                              (gpointer) gtk_dnd_window_configure_callback, this);
+    }
 }
 
 #endif
