@@ -4,15 +4,17 @@
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     1998-01-01
-// RCS-ID:      $Id: minifram.cpp 35650 2005-09-23 12:56:45Z MR $
+// RCS-ID:      $Id: minifram.cpp 49299 2007-10-21 18:07:29Z PC $
 // Copyright:   (c) Stefan Csomor
 // Licence:       wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #include "wx/wxprec.h"
 
+#if wxUSE_MINIFRAME
+
 #include "wx/minifram.h"
 
 IMPLEMENT_DYNAMIC_CLASS(wxMiniFrame, wxFrame)
 
-
+#endif // wxUSE_MINIFRAME
